============
Installation
============


From PyPi:

.. code-block:: python

    pip install sparkonda


From source:
Download the repo and install in a fresh environment

.. code-block:: python

    # Clone the package source:
    git clone https://github.com/moutai/sparkonda.git
    cd sparkonda
    python setup.py install


